@@ -9,7 +9,7 @@
 # delete.markup(input.text,markup.type="plain")
 # txt.to.words.ext(input.text,language="English")
 # make.samples(tokenized.input.data,sample.size=10000,sampling="no.sampling",
-#   sampling.with.replacement=FALSE
+#   sampling.with.replacement=FALSE)
 # txt.to.features(tokenized.text,features="w",ngram.size=1)
 #
 #################################################################
@@ -24,20 +24,22 @@ function(files,
          sampling = "no.sampling",
          sampling.with.replacement = FALSE,
          features = "w",
-         ngram.size = 1) {
+         ngram.size = 1,
+         preserve.case = FALSE) {
 
   loaded.corpus = load.corpus(files=files,corpus.dir=corpus.dir)
   # dropping file extensions from sample names
   names(loaded.corpus) = gsub("(\\.txt$)||(\\.xml$)||(\\.html$)||(\\.htm$)","",
                          names(loaded.corpus) )
-  # deleteing xml/html markup by applying the function "delete.markup"
-  loaded.corpus = lapply(loaded.corpus, delete.markup,
-                                        markup.type = markup.type)
+
+  # deleting xml/html markup by applying the function "delete.markup"
+  loaded.corpus = lapply(loaded.corpus,delete.markup,markup.type=markup.type)
   # deleting punctuation, splitting into words
   cat("slicing input text into single words...\n")
   loaded.corpus = lapply(loaded.corpus, txt.to.words.ext,
                                         language = language,
-                                        splitting.rule = splitting.rule)
+                                        splitting.rule = splitting.rule,
+                                        preserve.case = preserve.case)
   # normal sampling (if applicable); random sampling will be run later
   if(sampling == "normal.sampling") {
     loaded.corpus = make.samples(loaded.corpus,
